@@ -5,8 +5,7 @@ import unittest
 import whenIO
 
 
-# Setup
-minutesOffset = 240
+offsetMinutes = 240
 localToday = datetime.datetime(2009, 5, 1)
 specialPacks = [
     ('tod', 'today',     datetime.datetime(2009, 5, 1)),
@@ -22,10 +21,10 @@ specialPacks = [
 ]
 
 
-class TestWhenIO(unittest.TestCase):
+class Test(unittest.TestCase):
 
     def setUp(self):
-        self.whenIO = whenIO.WhenIO(minutesOffset=minutesOffset, localToday=localToday)
+        self.whenIO = whenIO.WhenIO(offsetMinutes=offsetMinutes, localToday=localToday)
 
     def test_format(self):
         'Test that formatting works properly'
@@ -33,7 +32,7 @@ class TestWhenIO(unittest.TestCase):
             self.assertEqual(self.whenIO.format(whens, fromUTC=False, **kw), whensString)
             if not hasattr(whens, '__iter__'):
                 whens = [whens]
-            self.assertEqual(self.whenIO.format([x + datetime.timedelta(minutes=minutesOffset) for x in whens], fromUTC=True, **kw), whensString)
+            self.assertEqual(self.whenIO.format([x + datetime.timedelta(minutes=offsetMinutes) for x in whens], fromUTC=True, **kw), whensString)
         # Test regular dates
         assertFormat(datetime.datetime(2009, 1, 1),         '01/01/2009 12am')
         assertFormat(datetime.datetime(2009, 1, 1, 3),      '01/01/2009 3am')
@@ -65,7 +64,7 @@ class TestWhenIO(unittest.TestCase):
             if not hasattr(whens, '__iter__'):
                 whens = [whens]
             self.assertEqual(self.whenIO.parse(whensString, toUTC=False)[0], whens)
-            self.assertEqual(self.whenIO.parse(whensString, toUTC=True)[0], [x + datetime.timedelta(minutes=minutesOffset) for x in whens])
+            self.assertEqual(self.whenIO.parse(whensString, toUTC=True)[0], [x + datetime.timedelta(minutes=offsetMinutes) for x in whens])
         # Test regular dates
         assertParse('12am',             datetime.datetime(2009, 5, 1, 0, 0))
         assertParse('12am text',             datetime.datetime(2009, 5, 1, 0, 0))
@@ -107,3 +106,9 @@ class TestWhenIO(unittest.TestCase):
         self.assertEqual(whenIO.parse_offset('-0400 UTC')[0], +240)
         self.assertEqual(whenIO.parse_offset('-0430 UTC')[0], +270)
         self.assertEqual(whenIO.parse_offset('-0600 UTC')[0], +360)
+
+    def test_interval(self):
+        self.assertEqual('7 days', whenIO.format_interval(whenIO.parse_interval('1 week 1 second')))
+        self.assertEqual('2 years', whenIO.format_interval(whenIO.parse_interval('1 year 8 months'), precision=1))
+        self.assertEqual('3 months 10 days', whenIO.format_interval(whenIO.parse_interval('3 months 9 days 23 hours'), precision=2))
+        self.assertEqual('8 days 8 hours', whenIO.format_interval(whenIO.parse_interval('200 hours')))
